import { __spread, __assign, __decorate, __param } from 'tslib';
import { Optional, ɵɵdefineInjectable, ɵɵinject, Injectable, NgModule } from '@angular/core';
import { tap } from 'rxjs/operators';

var _a, _b;
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["DEBUG"] = 0] = "DEBUG";
    LogLevel[LogLevel["INFO"] = 1] = "INFO";
    LogLevel[LogLevel["WARNING"] = 2] = "WARNING";
    LogLevel[LogLevel["ERROR"] = 3] = "ERROR";
})(LogLevel || (LogLevel = {}));
var AbstractNgxFancyLoggerService = /** @class */ (function () {
    function AbstractNgxFancyLoggerService() {
    }
    return AbstractNgxFancyLoggerService;
}());
var LoggerConfig = /** @class */ (function () {
    function LoggerConfig() {
        this.showTime = true;
        this.logLevel = LogLevel.DEBUG;
        this.showEmoji = true;
        this.showLabel = true;
        this.disableLogs = false;
        this.levelColor = {};
        this.levelEmoji = {};
    }
    return LoggerConfig;
}());
var DEFAULT_LEVEL_COLORS = (_a = {},
    _a[LogLevel.DEBUG] = 'black',
    _a[LogLevel.INFO] = 'steelblue',
    _a[LogLevel.WARNING] = 'orange',
    _a[LogLevel.ERROR] = 'red',
    _a);
var DEFAULT_EMOJIS = (_b = {},
    _b[LogLevel.DEBUG] = '👨‍💻',
    _b[LogLevel.INFO] = '🐬',
    _b[LogLevel.WARNING] = '⚡',
    _b[LogLevel.ERROR] = '😨',
    _b);
var NgxFancyLoggerService = /** @class */ (function () {
    function NgxFancyLoggerService(loggerConfig) {
        var _this = this;
        this.loggerConfig = loggerConfig;
        this.DEFAULT_CONFIG = new LoggerConfig();
        this.levelPrefix = {};
        this.showTime = function () {
            return _this.config.showTime ? " > " + new Date().toLocaleString() : '';
        };
        this.getStyles = function (level) { return "color:white;\n                                            background-color:" + (_this.config.levelColor[level] || DEFAULT_LEVEL_COLORS[level]) + ";\n                                            padding: 0px 2px;\n                                            border-radius: 2px"; };
        /** RxJS Debug Operator to generate Log */
        this.debugOperator = function (message, logLevel) {
            if (logLevel === void 0) { logLevel = LogLevel.DEBUG; }
            return tap(function (data) {
                _this.log(logLevel, message || '', data);
            });
        };
        this.config = this.DEFAULT_CONFIG;
        this.updateConfig(loggerConfig);
    }
    NgxFancyLoggerService.prototype.setPrefix = function () {
        if (this.config.disableLogs) {
            return;
        }
        for (var key in LogLevel) {
            if (!isNaN(Number(key))) {
                var prefix = this.config.showEmoji ? this.config.levelEmoji[key] || DEFAULT_EMOJIS[key] : '';
                if (this.config.showLabel) {
                    prefix += LogLevel[key];
                }
                this.levelPrefix[key] = prefix;
            }
        }
    };
    /** Common Log Method */
    NgxFancyLoggerService.prototype.log = function (level) {
        var args = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            args[_i - 1] = arguments[_i];
        }
        var method = 'log';
        switch (level) {
            case LogLevel.WARNING:
                method = 'warn';
                break;
            case LogLevel.ERROR:
                method = 'error';
                break;
        }
        if (this.config.disableLogs || (level < this.config.logLevel)) {
            return;
        }
        console[method].apply(console, __spread(["%c" + this.levelPrefix[level] + this.showTime(), this.getStyles(level)], args));
    };
    /** Update configuration, it will override configuration done through forRoot or Default Config */
    NgxFancyLoggerService.prototype.updateConfig = function (loggerConfig) {
        this.config = __assign(__assign({}, this.config), loggerConfig);
        this.setPrefix();
    };
    /** Reset to Default Configuration */
    NgxFancyLoggerService.prototype.resetConfig = function () {
        this.config = this.DEFAULT_CONFIG;
        this.setPrefix();
    };
    /** Display DEBUG level log */
    NgxFancyLoggerService.prototype.debug = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spread([LogLevel.DEBUG], args));
    };
    /** Display INFO level log */
    NgxFancyLoggerService.prototype.info = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spread([LogLevel.INFO], args));
    };
    /** Display WARNING Level log */
    NgxFancyLoggerService.prototype.warning = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spread([LogLevel.WARNING], args));
    };
    /** Display ERROR level log */
    NgxFancyLoggerService.prototype.error = function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        this.log.apply(this, __spread([LogLevel.ERROR], args));
    };
    /** Display Header on Console, You can configure color and fontSize of header */
    NgxFancyLoggerService.prototype.header = function (title, config) {
        if (config === void 0) { config = {}; }
        var styles = "font-size: " + (config.fontSize || 20) + "px; color:" + (config.color || 'steelblue') + ";   text-shadow: #ddd 2px 2px 2px";
        console.log("%c" + title, styles);
    };
    NgxFancyLoggerService.ctorParameters = function () { return [
        { type: LoggerConfig, decorators: [{ type: Optional }] }
    ]; };
    NgxFancyLoggerService.ɵprov = ɵɵdefineInjectable({ factory: function NgxFancyLoggerService_Factory() { return new NgxFancyLoggerService(ɵɵinject(LoggerConfig, 8)); }, token: NgxFancyLoggerService, providedIn: "root" });
    NgxFancyLoggerService = __decorate([
        Injectable({
            providedIn: 'root'
        }),
        __param(0, Optional())
    ], NgxFancyLoggerService);
    return NgxFancyLoggerService;
}());

var NgxFancyLoggerModule = /** @class */ (function () {
    function NgxFancyLoggerModule() {
    }
    NgxFancyLoggerModule_1 = NgxFancyLoggerModule;
    NgxFancyLoggerModule.forRoot = function (config) {
        return {
            ngModule: NgxFancyLoggerModule_1,
            providers: [
                { provide: LoggerConfig, useValue: config || {} },
                NgxFancyLoggerService
            ]
        };
    };
    var NgxFancyLoggerModule_1;
    NgxFancyLoggerModule = NgxFancyLoggerModule_1 = __decorate([
        NgModule({
            imports: [],
            providers: [NgxFancyLoggerService]
        })
    ], NgxFancyLoggerModule);
    return NgxFancyLoggerModule;
}());

/*
 * Public API Surface of ngx-fancy-logger
 */

/**
 * Generated bundle index. Do not edit.
 */

export { AbstractNgxFancyLoggerService, LogLevel, LoggerConfig, NgxFancyLoggerModule, NgxFancyLoggerService };
//# sourceMappingURL=ngx-fancy-logger.js.map
