import { MonoTypeOperatorFunction } from 'rxjs';
export declare enum LogLevel {
    DEBUG = 0,
    INFO = 1,
    WARNING = 2,
    ERROR = 3
}
export declare abstract class AbstractNgxFancyLoggerService {
    abstract debug(...args: any[]): void;
    abstract info(...args: any[]): void;
    abstract warning(...args: any[]): void;
    abstract error(...args: any[]): void;
}
export declare class LoggerConfig {
    showTime?: boolean;
    logLevel?: LogLevel;
    showEmoji?: boolean;
    showLabel?: boolean;
    disableLogs?: boolean;
    levelColor?: {
        [logLevel: number]: string;
    };
    levelEmoji?: {
        [logLevel: number]: string;
    };
}
export interface HeaderConfig {
    color?: string;
    fontSize?: number;
}
export declare class NgxFancyLoggerService implements AbstractNgxFancyLoggerService {
    private loggerConfig;
    private DEFAULT_CONFIG;
    private config;
    private levelPrefix;
    constructor(loggerConfig: LoggerConfig);
    private setPrefix;
    private showTime;
    private getStyles;
    /** Common Log Method */
    private log;
    /** Update configuration, it will override configuration done through forRoot or Default Config */
    updateConfig(loggerConfig: LoggerConfig | null | undefined): void;
    /** Reset to Default Configuration */
    resetConfig(): void;
    /** Display DEBUG level log */
    debug(...args: any[]): void;
    /** Display INFO level log */
    info(...args: any[]): void;
    /** Display WARNING Level log */
    warning(...args: any[]): void;
    /** Display ERROR level log */
    error(...args: any[]): void;
    /** Display Header on Console, You can configure color and fontSize of header */
    header(title: string, config?: HeaderConfig): void;
    /** RxJS Debug Operator to generate Log */
    debugOperator: <T>(message?: string, logLevel?: LogLevel) => MonoTypeOperatorFunction<T>;
}
